//
// SCSS sources for sveedocument ReStructuredText layout
//
@import "modular-scale";

.restructuredtext_container{
    h3, 
    h4, 
    h5, 
    h6{
        & a{
            text-decoration:none;
        }
    }

    // Topics
    .topic{
        padding: .5em 1em .5em 1em;
        border: 1px solid #cdcdcd;
        background-color: #f2f2f2;
        font-size:.9em;
        color:#384976;
        text-shadow: none;
    }
    .topic-title{
        font-size:1.1em;
        color:#365578;
        font-weight:bold;
    }

    // Admonitions
    .admonition-title{
        font-weight:bold;
    }
    .attention,
    .caution,
    .danger,
    .error,
    .hint,
    .important,
    .note,
    .tip,
    .warning{
        padding: .1em .7em .1em 3.4em;
        border: 1px solid #cdd9f7;
        background-color: #e8efff;
        font-size:.9em;
        color:#384976;
        text-shadow: none;
        background-repeat: no-repeat;
        background-position: .7em .7em;
        
        p + p{
            padding-top: .2em;
        }
    }
    .note{
        background-image: image-url("notices/about.png");
    }
    .attention,
    .important,
    .warning,
    .danger,
    .error{
        color:#763848;
        border: 1px solid #f7cdd7;
        background-color: #ffe8ed;
        background-image: image-url("notices/alert.png");
    }
    .danger,
    .error{
        background-image: image-url("notices/stop.png");
    }

    // Citations, codes, etc..
    blockquote{
        width:96%;
        margin-left:1%;
        margin-right:1%;
        padding:1%;
        border-left:3px solid #aaaaaa;
        background-color:#ffffff;
        text-shadow:none;
    }
    pre{
        width:98%;
        padding-left:1%;
        padding-right:1%;
        background-color:#e8efff;
        border:1px solid #d3d3d3;
        overflow:auto;
        text-shadow:none;
    }
    code{
        width:100%;
        background-color:#e8efff;
        border-bottom:1px solid #d3d3d3;
        overflow:auto;
    }

    tt.literal{
        background-color:#e8efff;
        border-bottom:1px solid #B0B0B0;
        text-shadow:none;
    }
    // Listes
    ul, ol{
        margin-left: ms(1);
    }
    dt {
        margin-top: ms(0);
        font-weight: bold;
    }
    dt:first-child {
        margin-top:0;
    }

    // Pygments
    .pygments-container{
        width: 100%;
        max-width: 100%;
        overflow:auto;
    }

    .pygmentstable,
    .pygments{
        width:98%;
        margin: .5em 1% .5em 1%;
        border-top:1px solid #aaaaaa;
        border-bottom:1px solid #aaaaaa;
    }
    .pygmentstable .pygments{
        width:auto;
        margin-left:0;
        margin-right:0;
        border:0;
    }
    .pygmentstable td.linenos{
        width:1%;
        padding-left:.4em;
        padding-right:.4em;
        border-right:1px solid #aaaaaa;
        text-align:right;
        background-color:#f0f0f0;
    }
    .pygmentstable td.code{
        padding-left:.4em;
        background-color:#ffffff;
    }
    .pygmentstable pre,
    .pygments pre{
        width:auto;
        padding-left:.5em;
        padding-right:.5em;
        background-color:transparent;
        border:0;
        overflow:auto;
    }
}