{% extends "base.html" %}
{% load mptt_tags autobreadcrumb %}

{% block head_title %}{% current_title_from_breadcrumbs %}{% endblock %}
{% block head_more_links %}
    {% include "sveedocuments/include_css.html" %}
{% endblock %}

{% block content %}
<div class="row">
    <h2>{% current_title_from_breadcrumbs %}</h2>

    <ul class="list-tree">
        {% recursetree page_list %}{% spaceless %}
            <li>
                <div class="tree-node-pointer">
                    <a href="{% url documents-page-details node.slug %}">{{ node.title }}</a>
                </div>
                {% if not node.is_leaf_node %}
                    <ul class="list-tree">{{ children }}</ul>
                {% endif %}
            </li>
        {% endspaceless %}{% endrecursetree %}
    </ul>
</div>
{% endblock %}
