@charset "UTF-8";
/*
 * Pikaday
 * Copyright © 2012 David Bushell | BSD & MIT license | http://dbushell.com/
 */
/* line 8, ../../scss/sveedocuments/_pikaday.scss */
.pika-single {
  z-index: 9999;
  display: block;
  position: relative;
  width: 240px;
  padding: 8px;
  color: #333;
  background: #fff;
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}
/* line 20, ../../scss/sveedocuments/_pikaday.scss */
.pika-single.is-hidden {
  display: none;
}
/* line 24, ../../scss/sveedocuments/_pikaday.scss */
.pika-single.is-bound {
  position: absolute;
  box-shadow: 0 5px 15px -5px rgba(0, 0, 0, 0.5);
}

/* line 31, ../../scss/sveedocuments/_pikaday.scss */
.pika-title {
  position: relative;
  text-align: center;
}
/* line 35, ../../scss/sveedocuments/_pikaday.scss */
.pika-title select {
  cursor: pointer;
  position: absolute;
  z-index: 9998;
  margin: 0;
  left: 0;
  top: 5px;
  opacity: 0;
}

/* line 46, ../../scss/sveedocuments/_pikaday.scss */
.pika-label {
  display: inline-block;
  *display: inline;
  position: relative;
  z-index: 9999;
  overflow: hidden;
  margin: 0;
  padding: 5px 3px;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  background-color: #fff;
}

/* line 61, ../../scss/sveedocuments/_pikaday.scss */
.pika-prev,
.pika-next {
  display: block;
  cursor: pointer;
  position: relative;
  outline: none;
  border: 0;
  padding: 0;
  width: 20px;
  height: 30px;
  background-color: transparent;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 75% 75%;
  white-space: nowrap;
  text-indent: 100%;
  overflow: hidden;
  opacity: .5;
  *position: absolute;
  *top: 0;
}
/* line 81, ../../scss/sveedocuments/_pikaday.scss */
.pika-prev:hover,
.pika-next:hover {
  opacity: 1;
}
/* line 84, ../../scss/sveedocuments/_pikaday.scss */
.pika-prev.is-disabled,
.pika-next.is-disabled {
  cursor: default;
  opacity: .2;
}

/* line 92, ../../scss/sveedocuments/_pikaday.scss */
.pika-prev,
.is-rtl .pika-next {
  float: left;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAUklEQVR42u3VMQoAIBADQf8Pgj+OD9hG2CtONJB2ymQkKe0HbwAP0xucDiQWARITIDEBEnMgMQ8S8+AqBIl6kKgHiXqQqAeJepBo/z38J/U0uAHlaBkBl9I4GwAAAABJRU5ErkJggg==");
  *left: 0;
}

/* line 99, ../../scss/sveedocuments/_pikaday.scss */
.pika-next,
.is-rtl .pika-prev {
  float: right;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAU0lEQVR42u3VOwoAMAgE0dwfAnNjU26bYkBCFGwfiL9VVWoO+BJ4Gf3gtsEKKoFBNTCoCAYVwaAiGNQGMUHMkjGbgjk2mIONuXo0nC8XnCf1JXgArVIZAQh5TKYAAAAASUVORK5CYII=");
  *right: 0;
}

/* line 105, ../../scss/sveedocuments/_pikaday.scss */
.pika-select {
  display: inline-block;
  *display: inline;
}

/* line 110, ../../scss/sveedocuments/_pikaday.scss */
.pika-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
  border: 0;
}
/* line 116, ../../scss/sveedocuments/_pikaday.scss */
.pika-table th, .pika-table td {
  width: 14.285714285714286%;
}
/* line 120, ../../scss/sveedocuments/_pikaday.scss */
.pika-table th {
  color: #999;
  font-size: 12px;
  line-height: 25px;
  font-weight: bold;
  text-align: center;
}

/* line 129, ../../scss/sveedocuments/_pikaday.scss */
.pika-button {
  cursor: pointer;
  display: block;
  outline: none;
  border: 0;
  margin: 0;
  width: 100%;
  padding: 5px;
  color: #666;
  font-size: 12px;
  line-height: 15px;
  text-align: right;
  background: #f5f5f5;
}
/* line 143, ../../scss/sveedocuments/_pikaday.scss */
.pika-button:hover {
  color: #fff !important;
  background: #ff8000 !important;
  box-shadow: none !important;
  border-radius: 3px !important;
}

/* line 151, ../../scss/sveedocuments/_pikaday.scss */
.is-today .pika-button {
  color: #33aaff;
  font-weight: bold;
}

/* line 156, ../../scss/sveedocuments/_pikaday.scss */
.is-selected .pika-button {
  color: #fff;
  font-weight: bold;
  background: #33aaff;
  box-shadow: inset 0 1px 3px #178fe5;
  border-radius: 3px;
}

/* line 164, ../../scss/sveedocuments/_pikaday.scss */
.is-disabled .pika-button {
  pointer-events: none;
  cursor: default;
  color: #999;
  opacity: .3;
}

/* line 14, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid, ul.list-tree-fluid ul {
  margin: 0 1.4em 1.4em 1.4em;
  padding: 0;
  list-style-type: none;
  background-image: url('../../images/list-tree/list-tree-alt-vline.png?1356825720');
  background-repeat: repeat-y;
}

/* line 22, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid ul {
  margin: 0 0 0 .5em;
  margin-left: 1.3em;
  padding-top: .6em;
}
/* line 28, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li {
  margin: 0;
  padding: 0 0 0 .6em;
  background-image: url('../../images/list-tree/list-tree-alt-node.png?1356825720');
  background-repeat: no-repeat;
  background-position: 0 1.2em;
  color: #369;
}
/* line 37, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li.last, ul.list-tree-fluid li:last-child {
  background-image: url('../../images/list-tree/list-tree-alt-lastnode.png?1356825720');
  background-color: #ffffff;
  background-position: 0 -1em;
}
/* line 43, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li .indicator {
  padding: 1.4px 5px;
  float: left;
  text-align: center;
  border: 1px solid black;
  border-right: 0;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  -ms-border-radius: 3px;
  -o-border-radius: 3px;
  border-radius: 3px;
}
/* line 51, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li .indicator span {
  display: block;
  border: 0;
}
/* line 56, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li .indicator i {
  font-size: 18px;
  line-height: 0;
}
/* line 64, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid .button-group li, ul.list-tree-fluid .button.split li {
  background-image: none;
}
/* line 69, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid li + li {
  padding-top: .6em;
}
/* line 73, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid.hidden {
  opacity: 0.5;
}
/* line 76, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid.hidden:hover, ul.list-tree-fluid.hidden.hover_highlight {
  opacity: 1.0;
}
/* line 85, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid .children.hidden_parent {
  opacity: 0.5;
}
/* line 89, ../../scss/sveedocuments/board.scss */
ul.list-tree-fluid .children.hidden_parent li.last,
ul.list-tree-fluid .children.hidden_parent li:last-child {
  background-position: 0 -2.4em;
}

/* line 97, ../../scss/sveedocuments/board.scss */
.DjangoCodeMirror {
  width: 100% !important;
}
